Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetClient ¶
func GetClient(master string) (*kubernetes.Clientset, error)
GetClient creates a config from the given master and kubeconfig location on disk, then creates a new kubernetes Clientset from that config
func New ¶
New initializes a new Kubernetes backend.
Types ¶
This section is empty.
Source Files
¶
- client.go
- cronjob.go
- job.go
- kube.go
- secret.go
Click to show internal directories.
Click to hide internal directories.