package
Version:
v0.1.3
Opens a new window with list of versions in this module.
Published: Jan 8, 2019
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
AbortWithError aborts the request and returns the error in the response body
func WriteResponse(
c *gin.Context,
statusCode int,
responseBody interface{},
)
WriteResponse ...
Source Files
¶
Click to show internal directories.
Click to hide internal directories.