Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateItem ¶
func CreateItem(scanRequest *types.ScanRequest, item interface{}) presidio.Item
CreateItem creates a new instance of scanned item according to the specified kind
Types ¶
type ScanFunc ¶
type ScanFunc func(item interface{}) error
ScanFunc is the function the is executed on the scanned item
type Scanner ¶
type Scanner interface {
//Init the scanner
Init(inputConfig *types.CloudStorageConfig)
//Scan walks over the items to scan and executes ScanFunc on each of the items
Scan(fn ScanFunc) error
}
Scanner interface represent the supported scanner methods.
func CreateScanner ¶
func CreateScanner(scanRequest *types.ScanRequest) Scanner
CreateScanner creates a new instance of the scanner according to the specified kind
func NewStorageScanner ¶
func NewStorageScanner(inputConfig *types.CloudStorageConfig) Scanner
NewStorageScanner returns new instance of DB Data writer
Source Files
¶
- factory.go
- scanner.go
- storage-item.go
- storage-scanner.go
Click to show internal directories.
Click to hide internal directories.