Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Datasink ¶
type Datasink interface {
// Init the specified datasink
Init()
// WriteAnalyzeResults write the analyzer results to the specified datasink
WriteAnalyzeResults(results []*types.AnalyzeResult, path string) error
// WriteAnonymizeResults write the analyzer results to the specified datasink
WriteAnonymizeResults(result *types.AnonymizeResponse, path string) error
}
Datasink represents the different data output types such as SQL and Datawarehouse
Source Files
¶
- datasink.go
Click to show internal directories.
Click to hide internal directories.